import argparse

from tsukuda_fib_py.fib_calcs.fib_number import recurring_fibonacci_number


def fib_numb() -> None:
    parser = argparse.ArgumentParser(
        description="Calculate Fibonacci numbers",
    )
    parser.add_argument(
        "--number",
        action="store",
        type=int,
        required=True,
        help="Fibonacci number to be calculated",
    )
    args = parser.parse_args()
    print(
        f"Your Fibonacci number is: "\
        f"{recurring_fibonacci_number (number=args.number)}"
    )



def recurring_fibonacci_number(number: int) -> int:
    if number < 0:
        raise ValueError(
            "Fibonacci has to be equal or above zero"
        )
    elif number <= 1:
        return number
    else:
        return recurring_fibonacci_number(number - 1) + recurring_fibonacci_number(number - 2)



from setuptools import setup, find_packages
import pathlib


with open("README.md", "r") as fh:
    long_description = fh.read()

with open(str(pathlib.Path(__file__).parent.absolute()) + "/tsukuda_fib_py/version.py", "r") as fh:
    version = fh.read().split("=")[1].replace("'", "")

setup(
    name="tsukuda_fib_py",
    version=version,
    author="tsukudamayo",
    author_email="tsukudamayo@gmail.com",
    description="Calculates a FIbonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tsukudamayo/tsukuda-fib-py",
    install_requires=[
        "PyYAML>=4.1.2",
        "dill>=0.2.8",
    ],
    extras_require={
        "server": ["Flask>=1.0.0"]
    },
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    entry_points={
        "console_scripts": [
            "fib-number = tsukuda_fib_py.cmd.fib_numb:fib_numb",
        ],
    },
    python_requires=">=3",
    test_requires=["pytest"],
)
